/*
 * Yggdrasil: Minecraft authentication server
 * Copyright (C) 2023 0xf8.dev@proton.me
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

use anyhow::{bail, Result};
use log::info;

use structs::account::Account;
use yggdrasil::*;

use crate::dbtool::Args;

pub struct AddAccount {}

impl AddAccount {
    pub async fn exec(args: Args, db: &Database) -> Result<()> {
        if args.arguments.len() < 3 { bail!("Not enough arguments. add-account <email> <lang> <country>") };

        // Get args
        let email   = args.arguments.get(0).unwrap().to_lowercase();
        let lang    = args.arguments.get(1).unwrap().to_lowercase();
        let country = args.arguments.get(2).unwrap().to_string();

        // Validate args
        if !Validate::email(&email)     { bail!("Invalid email; ex: \"user@example\"") }
        if !Validate::lang(&lang)       { bail!("Invalid language; ex: \"en-us\"") }
        if !Validate::country(&country) { bail!("Invalid country; ex: \"US\"") }

        // Get password
        let password = Input::password().await?;

        info!("Email: {email}");
        info!("Lang: {lang}");
        info!("Country: {country}");
        info!("Password: ...{{{}}}", password.len());

        // Create new account
        let account = Account::new(db, email, lang, country, password).await?;

        info!("New account ID: {}", account.id);

        Ok(())
    }
}

