/*
 * Yggdrasil: Minecraft authentication server
 * Copyright (C) 2023 0xf8.dev@proton.me
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
 */


use std::str::FromStr;

use anyhow::{bail, Result};
use log::info;

use structs::profile::Profile;
use yggdrasil::*;

use crate::dbtool::Args;
use crate::util::structs::account::Account;

pub struct AttachProfile {}

impl AttachProfile {
    pub async fn exec(args: Args, db: &Database) -> Result<()> {
        if args.arguments.len() < 2 { bail!("Not enough arguments. attach-profile <account-id> <profile-id>") }

        // Get ids
        let account_id = i64::from_str(args.arguments.get(0).unwrap())?;
        let profile_id = i64::from_str(args.arguments.get(1).unwrap())?;

        // Get account
        let Some(account) = Account::from_id(db, account_id).await else {
            bail!("Account(id = {account_id}) doesn't exist")
        };

        // Get profile
        let Some(profile) = Profile::from_id(db, profile_id).await else {
            bail!("Profile(id = {profile_id}) doesn't exist")
        };

        account.set_selected_profile(db, &profile).await
    }
}
