/*
 * Yggdrasil: Minecraft authentication server
 * Copyright (C) 2023 0xf8.dev@proton.me
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

use anyhow::{bail, Result};
use dotenvy::dotenv;
use log::{info, warn};
use log::LevelFilter::Debug;

use yggdrasil::*;

mod server;

#[async_std::main]
async fn main() -> Result<()> {
    let _ = dotenv();

    // Early catch
    if std::env::var("DATABASE_URL").is_err() {
        bail!("DATABASE_URL needs to be set.")
    }

    // Start logger
    if std::env::var("DEBUG").unwrap_or(String::new()).to_lowercase() == "on" {
        femme::with_level(Debug);
    } else {
        femme::start();
    }

    // Load config
    let config = Config::load()?;
    info!("Config location: {}", config.location.display());

    // Load database
    let db = Database::init(config).await?;
    info!("Database URL: {}", std::env::var("DATABASE_URL")?);

    let wrapper = DatabaseWrapper { db };

    // Start server
    server::start(&wrapper.db).await?;

    warn!("Server stopped!");

    // Cleanup
    Ok(log::logger().flush())
}
