/*
 * Yggdrasil: Minecraft authentication server
 * Copyright (C) 2023 0xf8.dev@proton.me
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

use anyhow::anyhow;
use tide::{prelude::*, Request, Result};

use yggdrasil::Database;
use yggdrasil::errors::YggdrasilError;
use yggdrasil::structs::token::Token;

#[derive(Deserialize, Debug)]
struct InvalidateBody {
    #[serde(rename = "accessToken")]
    access_token: String,

    #[serde(rename = "clientToken")]
    client_token: String,
}

pub async fn invalidate(mut req: Request<Database>) -> Result {
    let Ok(body) = req.body_json::<InvalidateBody>().await else {
        // No credentials
        return Err(YggdrasilError::new_bad_request("Credentials can not be null.").into())
    };

    let Some(token) = Token::from_access_token(req.state(), body.access_token).await else {
        // Token doesn't exist
        return Err(YggdrasilError::new_unauthorized("Invalid token.").into())
    };

    // Verify token
    if !token.validate_with(req.state(), body.client_token, false).await? {
        return Err(YggdrasilError::new_unauthorized("Invalid token.").into())
    }

    // Delete token
    token.delete(req.state()).await?;

    Ok("".into())
}