/*
 * Yggdrasil: Minecraft authentication server
 * Copyright (C) 2023 0xf8.dev@proton.me
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

use log::debug;
use tide::{prelude::*, Request, Result};

use yggdrasil::*;

pub fn nest(db: Database) -> tide::Server<Database> {
    debug!("Loading nest");

    let mut nest = tide::with_state(db.to_owned());

    nest.at("/").get(authlib_meta);
    nest.at("/authserver").nest(super::auth::nest(db.to_owned()));
    nest.at("/sessionserver/session/minecraft").nest(super::session::nest(db.to_owned()));

    nest.at("/api/profiles/minecraft").nest(super::profile::nest(db.to_owned()));

    nest
}

async fn authlib_meta(req: Request<Database>) -> Result {
    let config = &req.state().config;
    Ok(json!({
        "meta": {
            "implementationName": std::env!("CARGO_PKG_NAME"),
            "implementationVersion": std::env!("CARGO_PKG_VERSION"),
            "feature.no_mojang_namespace": config.no_mojang_namespace,
            "links": {
                "homepage": config.external_base_url
            },
            "serverName": config.server_name,
        },
        "skinDomains": config.skin_domains
        // TODO: public key signature
    }).into())
}
