/*
 * Yggdrasil: Minecraft authentication server
 * Copyright (C) 2023 0xf8.dev@proton.me
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
 */


use log::debug;

use yggdrasil::*;

mod profile;
mod skin;
mod cape;

pub fn nest(db: Database) -> tide::Server<Database> {
    debug!("Loading nest");

    let mut nest = tide::with_state(db);

    nest.at("/").post(profile::profiles);

    nest.at("/:uuid").get(profile::profile);

    nest.at("/:uuid/names").get(profile::name_history);

    nest.at("/:uuid/skin").put(skin::put_skin);
    nest.at("/:uuid/skin/:skin").delete(skin::delete_skin);

    nest.at("/:uuid/capes").put(cape::upload_cape);
    nest.at("/:uuid/cape/active").put(cape::change_cape);
    nest.at("/:uuid/cape/active").delete(cape::delete_cape);

    nest
}
