/*
 * Yggdrasil: Minecraft authentication server
 * Copyright (C) 2023 0xf8.dev@proton.me
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
 */


use std::str::FromStr;
use std::time::Duration;

use anyhow::Result;
use futures::executor;
use log::debug;
use sqlx::{ConnectOptions, SqlitePool};
use sqlx::sqlite::{SqliteConnectOptions, SqlitePoolOptions};

use crate::*;

#[derive(Clone, Debug)]
pub struct Database {
    pub pool: SqlitePool,
    pub config: Config,
}

impl Database {
    pub async fn init(config: Config) -> Result<Database> {
        let mut options = SqliteConnectOptions::from_str(std::env::var("DATABASE_URL")?.as_str())?;
        options.log_statements(log::LevelFilter::Off);
        options.log_slow_statements(log::LevelFilter::Info, Duration::from_secs(2));

        Ok(Self {
            pool: SqlitePoolOptions::new()
                .max_connections(5)
                .connect_with(options)
                .await?,
            config,
        })
    }
}

pub struct DatabaseWrapper {
    pub db: Database
}

impl Drop for DatabaseWrapper {
    fn drop(&mut self) {
        debug!("Dropping database");
        executor::block_on(self.db.pool.close());
    }
}

